==========================
django-nomad-base-accounts
==========================

Overview
========

This Django app from Nomadblue.com provides the basic foundations to
manage email-based users. Registration, login, and settings management
to update email and password.
